################################################################################
# Title: Gc-Gf: 2 Factor model
# File: Session L - Computer Programs/prog12_gcgf_2fac.R
# Source File: Session L - Computer Programs/prog12_gcgf_2fac.out
# Created: Tue Jun 21 00:15:18 2011
################################################################################
# TranslateOpenMx library (Version 0.1)
################################################################################

# load OpenMx
library(OpenMx)

# load data
rto8age2 <- read.table('rto8age2.dat', na.string="c('USEVAR' , '='      , 'comp_06', 'voca_06', 'bloc_06', 'obje_06')")
names(rto8age2) <- c('id', 'moeducat', 'age_06', 'info_06', 'comp_06',
    'simi_06', 'voca_06', 'picc_06', 'pica_06', 'bloc_06',
    'obje_06', 'age_11', 'info_11', 'comp_11', 'simi_11',
    'voca_11', 'picc_11', 'pica_11', 'bloc_11', 'obje_11')

# specify model
Gc_Gf_Model <- mxModel("Gc_Gf_ 2 Factor model",
    type="RAM",
    # specify data and variables
    mxData(rto8age2, "raw"),
    manifestVars=c('comp_06', 'voca_06', 'bloc_06', 'obje_06'),
    latentVars=c('gc_06', 'gf_06'),
    # specify 'BY' parameter(s)
    mxPath(from='gc_06', to=c('comp_06', 'voca_06'), arrows=1,
        free=TRUE, values=c(6.420, 5.550), labels=c('p1', 'p2')),
    # specify 'BY' parameter(s)
    mxPath(from='gf_06', to=c('bloc_06', 'obje_06'), arrows=1,
        free=TRUE, values=c( 4.576, 12.829), labels=c('p3', 'p4')),
    # specify 'WITH' parameter(s)
    mxPath(from='gc_06', to='gf_06', arrows=2,
        free=TRUE, values=0.641, labels='p5'),
    # specify 'Mean' parameter(s)
    mxPath(from='one', to=c('gc_06', 'gf_06'), arrows=1,
        free=FALSE, values=0, labels=NA),
    # specify 'Intercept' parameter(s)
    mxPath(from='one', to=c('comp_06', 'voca_06', 'bloc_06', 'obje_06'), arrows=1,
        free=TRUE, values=c(21.797, 20.396,  6.942, 25.258), labels=c('p6', 'p7', 'p8', 'p9')),
    # specify 'Variance' parameter(s)
    mxPath(from=c('gc_06', 'gf_06'), to=c('gc_06', 'gf_06'), arrows=2,
        free=FALSE, values=1, labels=NA),
    # specify 'Variance' parameter(s)
    mxPath(from=c('comp_06', 'voca_06', 'bloc_06', 'obje_06'), to=c('comp_06', 'voca_06', 'bloc_06', 'obje_06'), arrows=2,
        free=TRUE, values=c( 53.220,   8.592,  22.391, 102.878), labels=c('p10', 'p11', 'p12', 'p13')))

# run model
Gc_Gf_ModelResults <- mxRun(Gc_Gf_Model)

# view summary of results
summary(Gc_Gf_ModelResults)
