DATA wisc;
	INFILE 'G:\Section I\Data Analysis\wisc4vpe.dat';
*	INFILE 'D:\Documents and Settings\kjgrimm\My Documents\Laptop Documents\Organization\Workshops\APA-ATI LSEM 2009\Section I\Data Analysis\wisc4vpe.dat';
	INPUT Verb1 Verb2 Verb4 Verb6 Perf1 Perf2 Perf4 Perf6 Moeducat;
	id = _N_;
RUN;
PROC FREQ;
	TABLES moeducat;
RUN;
PROC SORT;
	BY moeducat;
RUN;

SYMBOL COLOR = salmon HEIGHT = .8;
GOPTIONS FTEXT = swiss HTEXT = 1.5;
AXIS1 MINOR = none COLOR = black LABEL = (HEIGHT = 2 ANGLE = 90 ROTATE = 0 'Verbal Ability in First Grade') ORDER = (0 to 80 by 20);
AXIS2 MINOR = none COLOR = black LABEL = (HEIGHT = 2 'Mother''s Education Category');

TITLE Box Plot for Verbal Ability in Grade 1;
PROC BOXPLOT DATA = wisc;
	PLOT verb1 * moeducat/ 	CFRAME = white
							CBOXES = black
							CBOXFILL = ywh
							VAXIS = axis1 HAXIS=axis2;
RUN;

AXIS3 MINOR = none COLOR = black LABEL = (HEIGHT = 2 ANGLE = 90 ROTATE = 0 'Verbal Ability in Second Grade') ORDER = (0 to 80 by 20);
TITLE Box Plot for Verbal Ability in Grade 2;
PROC BOXPLOT DATA = wisc;
	PLOT verb2 * moeducat/ 	CFRAME = white
							CBOXES = black
							CBOXFILL = ywh
							VAXIS = axis3 HAXIS=axis2;
RUN;

AXIS4 MINOR = none COLOR = black LABEL = (HEIGHT = 2 ANGLE = 90 ROTATE = 0 'Verbal Ability in Fourth Grade') ORDER = (0 to 80 by 20);
TITLE Box Plot for Verbal Ability in Grade 4;
PROC BOXPLOT DATA = wisc;
	PLOT verb4 * moeducat/ 	CFRAME = white
							CBOXES = black
							CBOXFILL = ywh
							VAXIS = axis4 HAXIS=axis2;
RUN;

AXIS5 MINOR = none COLOR = black LABEL = (HEIGHT = 2 ANGLE = 90 ROTATE = 0 'Verbal Ability in Sixth Grade') ORDER = (0 to 80 by 20);
TITLE Box Plot for Verbal Ability in Grade 4;
PROC BOXPLOT DATA = wisc;
	PLOT verb6 * moeducat/ 	CFRAME = white
							CBOXES = black
							CBOXFILL = ywh
							VAXIS = axis5 HAXIS=axis2;
RUN;

PROC MEANS DATA = wisc MAXDEC = 2;
	CLASS moeducat;
	VAR verb1 verb2 verb4 verb6;
RUN;

*Trajectories of Groups based on 'Multilevel' Growth Model;
DATA sim1;
	nu_i = 16.469;
	nu_s = 21.083;

	delta_i1 = 4.716;
	delta_i2 = 5.983;

	delta_s1 = 3.977;
	delta_s2 = 6.463;

	ARRAY A[4] (0 .233 .527 1);

	DO G = 1 to 3;
		IF G = 1 THEN i = nu_i;
		IF G = 1 THEN s = nu_s;
		IF G = 2 THEN i = nu_i + delta_i1;
		IF G = 2 THEN s = nu_s + delta_s1;
		IF G = 3 THEN i = nu_i + delta_i2;
		IF G = 3 THEN s = nu_s + delta_s2;
	
		DO t = 1 to 4;
			pred = i + s * A[t];
			IF t = 1 THEN grade = 1;
			IF t = 2 THEN grade = 2;
			IF t = 3 THEN grade = 4;
			IF t = 4 THEN grade = 6;
			OUTPUT;
		END;
	END;
RUN;

GOPTIONS RESET = all;
GOPTIONS
	ftext = triplex
	htext = 1.8
	ctext = black;	
PROC GPLOT DATA = sim1;
	TITLE1 'Predicted Trajectories';
	SYMBOL1
		i=join
		r=1
		v=dot
		w=6
		h=.7
		c=black;
	SYMBOL2
		i=join
		r=1
		v=dot
		w=6
		h=.7
		c=blue;
	SYMBOL3
		i=join
		r=1
		v=dot
		w=6
		h=.7
		c=red;
	AXIS1
		LABEL = (F=triplex H = 2 A=90 'Verbal Ability')
		ORDER = (0 to 80 BY 10)
		MINOR = none
		OFFSET= (3 pct, 3 pct);
	AXIS2
		LABEL = (F=triplex H = 2 'Grade')
		ORDER = (1 to 6 BY 1)
		OFFSET= (3 PCT, 3 PCT)
		MINOR = none;
	PLOT pred*grade=g/NOLEGEND VAXIS= AXIS1 HAXIS=AXIS2;
RUN;


*Longitudinal Plots of Verbal Ability by Mother Education Groups;
DATA wisc_long;
	SET wisc;
	ID = _N_;
RUN;
DATA wisc_long1;
	SET wisc_long;
	verb = verb1; perf = perf1; grade = 1;	OUTPUT;
	verb = verb2; perf = perf2; grade = 2;	OUTPUT;
	verb = verb4; perf = perf4; grade = 4;	OUTPUT;
	verb = verb6; perf = perf6; grade = 6;	OUTPUT;
KEEP id verb perf grade moeducat;
RUN;

PROC SORT DATA = wisc_long1;
	BY moeducat;
RUN;
PROC GPLOT DATA = wisc_long1;
	SYMBOL1
		i=join
		r=500
		v=dot
		w=2
		h=.7
		l=1
		c=black;
	AXIS1
		LABEL = (F=triplex H = 2 A=90 'Verbal Ability')
		ORDER = (0 to 80 BY 10)
		MINOR = none
		OFFSET= (3 pct, 3 pct);
	AXIS2
		LABEL = (F=triplex H = 2 'Grade')
		ORDER = (1 to 6 BY 1)
		OFFSET= (3 PCT, 3 PCT)
		MINOR = none;
	PLOT verb*grade=id/NOLEGEND VAXIS= AXIS1 HAXIS=AXIS2;
	BY moeducat;
RUN;


*Multi-level Linear Growth Curve with Mother's Education as Predictor;
DATA wisc_long2;
	SET wisc_long1;
	grade_1 = grade - 1;

	IF moeducat = 1 THEN momHS = 1; ELSE momHS = 0;
	IF moeducat = 2 THEN momHSp = 1; ELSE momHSp = 0;
RUN;

PROC MIXED DATA = wisc_long2 NOCLPRINT METHOD=ML COVTEST IC;
	CLASS id;
	MODEL Verb = grade_1 momHS momHSp grade_1*momHS grade_1*momHSp / SOLUTION DDFM=BW CHISQ;
	RANDOM INTERCEPT grade_1 / SUBJECT=id TYPE=UNR;
RUN;

*Mixture Models through PROC TRAJ - Note: No within-class variation;
*Linear Growth Model;
PROC MIXED DATA = wisc_long2 NOCLPRINT METHOD=ML COVTEST;
	CLASS id;
	MODEL Verb = grade_1 / SOLUTION DDFM=BW CHISQ;
	RANDOM INTERCEPT grade_1 / SUBJECT=id TYPE=UNR;
RUN;
*Mixture Models through PROC TRAJ - Note: No within-class variation;
DATA wisc1;
	SET wisc;
	grade1 = 0; grade2 = 1; grade4 = 3; grade6 = 5;
RUN;
PROC TRAJ DATA=wisc1 OUTPLOT=OP OUTSTAT=OUTFILE OUT=OF ITDETAIL;
    ID id;
    VAR verb1 verb2 verb4 verb6;
    INDEP grade1 grade2 grade4 grade6;
	MIN 0;
	MAX 100;
    MODEL CNORM;
    NGROUPS 2;
    ORDER 1 1;
RUN;

