##########################################

### Autoregressive Model 2 - Bi-Coupling

data<-read.table("nlsy_ach_bpi1.dat",header=F,colClasses="numeric",
na.string=".")

#paste command - pattern to name columns
#paste0 = paste command with no separation
#paste0("tot",4:14) = "tot4","tot5",..."tot14"

names(data)<-c("id","race","sex","m_birth","ldisabil", 
	paste0("dep",4:14),paste0("tot",4:14),
	paste0("anti",4:14),paste0("axdp",4:14),
	paste0("math",5:14),paste0("rec",5:14),
	paste0("comp",4:14),paste0("pvt",4:14))

t<-which(data$ldisabil==1)
data<-data[-t,]
#access data columns easily by attaching it
attach(data)



##Define variables

    data$total8  = (((dep8  + anti8  + axdp8)-5.039)/4.076)*10+50;
    data$total9  = (((dep9  + anti9  + axdp9)-5.039)/4.076)*10+50;
    data$total10 = (((dep10 + anti10 + axdp10)-5.039)/4.076)*10+50;
    data$total11 = (((dep11 + anti11 + axdp11)-5.039)/4.076)*10+50;
    data$total12 = (((dep12 + anti12 + axdp12)-5.039)/4.076)*10+50;
    data$total13 = (((dep13 + anti13 + axdp13)-5.039)/4.076)*10+50;
    data$total14 = (((dep14 + anti14 + axdp14)-5.039)/4.076)*10+50;
##Define variables

    data$pvt8 = ((pvt8-82.130)/16.745)*10+50;
    data$pvt9 = ((pvt9-82.130)/16.745)*10+50;
    data$pvt10 = ((pvt10-82.130)/16.745)*10+50;
    data$pvt11 = ((pvt11-82.130)/16.745)*10+50;
    data$pvt12 = ((pvt12-82.130)/16.745)*10+50;
    data$pvt13 = ((pvt13-82.130)/16.745)*10+50;
    data$pvt14 = ((pvt14-82.130)/16.745)*10+50;

###########################3
###########################
### OBSERVED ##########
##########################



acl3_obs<-'

#####
#BPI#
#####


## AutoRegressions
total9~beta_1*total8
total10~beta_1*total9
total11~beta_1*total10
total12~beta_1*total11
total13~beta_1*total12
total14~beta_1*total13

# Means for Total
total8~start(50.009)*1
total9~start(13.190)*1
total10~start(12.711)*1
total11~start(13.290)*1
total12~start(13.406)*1
total13~start(13.589)*1
total14~start(13.525)*1

##Time-Specific Variance
total8~~start(99.960)*total8
total9~~su*total9
total10~~su*total10
total11~~su*total11
total12~~su*total12
total13~~su*total13
total14~~su*total14

#####
#PVT#
#####

## AutoRegressions
pvt9~gamma_1*pvt8
pvt10~gamma_1*pvt9
pvt11~gamma_1*pvt10
pvt12~gamma_1*pvt11
pvt13~gamma_1*pvt12
pvt14~gamma_1*pvt13

#Means for PVT
pvt8~start(50.009)*1
pvt9~start(10.678)*1
pvt10~start(11.225)*1
pvt11~start(10.213)*1
pvt12~start(10.804)*1
pvt13~start(10.989)*1
pvt14~start(9.776)*1

##Time-Specific Variance
pvt8~~start(97.213)*pvt8
pvt9~~sigma2_s*pvt9
pvt10~~sigma2_s*pvt10
pvt11~~sigma2_s*pvt11
pvt12~~sigma2_s*pvt12
pvt13~~sigma2_s*pvt13
pvt14~~sigma2_s*pvt14


##MULTIVARIATE INFO

#Specific Covariance
    pvt8   ~~(c_su)*total8  
    pvt9   ~~(c_su)*total9  
    pvt10  ~~(c_su)*total10 
    pvt11  ~~(c_su)*total11
    pvt12  ~~(c_su)*total12
    pvt13  ~~(c_su)*total13
    pvt14  ~~(c_su)*total14

#Couplings
    total9   ~(gamma_2)*pvt8  
    total10  ~(gamma_2)*pvt9 
    total11  ~(gamma_2)*pvt10
    total12  ~(gamma_2)*pvt11
    total13  ~(gamma_2)*pvt12
    total14  ~(gamma_2)*pvt13

    pvt9   ~(beta_2)*total8  
    pvt10  ~(beta_2)*total9 
    pvt11  ~(beta_2)*total10
    pvt12  ~(beta_2)*total11
    pvt13  ~(beta_2)*total12
    pvt14  ~(beta_2)*total13

'

acl3_obs_fit<-lavaan(acl3_obs,data=data,missing='ML',fixed.x=F)

summary(acl3_obs_fit)