
#### Bivariate Latent Growth Model

data<-read.table("nlsy_ach_bpi1.dat",header=F,colClasses="numeric",
na.string=".")

#paste command - pattern to name columns
#paste0 = paste command with no separation
#paste0("tot",4:14) = "tot4","tot5",..."tot14"

names(data)<-c("id","race","sex","m_birth","ldisabil", 
	paste0("dep",4:14),paste0("tot",4:14),
	paste0("anti",4:14),paste0("axdp",4:14),
	paste0("math",5:14),paste0("rec",5:14),
	paste0("comp",4:14),paste0("pvt",4:14))

t<-which(data$ldisabil==1)
data<-data[-t,]
#access data columns easily by attaching it
attach(data)



##Define variables

    data$total8  = (((dep8  + anti8  + axdp8)-5.039)/4.076)*10+50;
    data$total9  = (((dep9  + anti9  + axdp9)-5.039)/4.076)*10+50;
    data$total10 = (((dep10 + anti10 + axdp10)-5.039)/4.076)*10+50;
    data$total11 = (((dep11 + anti11 + axdp11)-5.039)/4.076)*10+50;
    data$total12 = (((dep12 + anti12 + axdp12)-5.039)/4.076)*10+50;
    data$total13 = (((dep13 + anti13 + axdp13)-5.039)/4.076)*10+50;
    data$total14 = (((dep14 + anti14 + axdp14)-5.039)/4.076)*10+50;
##Define variables

    data$pvt8 = ((pvt8-82.130)/16.745)*10+50;
    data$pvt9 = ((pvt9-82.130)/16.745)*10+50;
    data$pvt10 = ((pvt10-82.130)/16.745)*10+50;
    data$pvt11 = ((pvt11-82.130)/16.745)*10+50;
    data$pvt12 = ((pvt12-82.130)/16.745)*10+50;
    data$pvt13 = ((pvt13-82.130)/16.745)*10+50;
    data$pvt14 = ((pvt14-82.130)/16.745)*10+50;



biv_lca<-'

#####
#BPI#
#####

## Level

b_0n=~ 1*total8+1*total9+1*total10+1*total11+1*total12+
1*total13+1*total14
b_0n ~ start(50)*1
b_0n ~~ start(15)*b_0n

## SLOPE - Growth

b_1n =~ 0*total8+total9+total10+total11+total12+
total13+1*total14
b_1n~beta_1*1
b_1n~~sigma2_b1*b_1n

b_1n~~sb1b0*b_0n

#Means of total
total8+total9+total10+total11+total12+total13+total14~0*1

#Specific Variance of Total
total8~~si*total8
total9~~si*total9
total10~~si*total10
total11~~si*total11
total12~~si*total12
total13~~si*total13
total14~~si*total14


#####
#PVT#
#####

##Level 

h_0n =~ 1*pvt8+1*pvt9+1*pvt10+1*pvt11+1*pvt12+1*pvt13+1*pvt14
h_0n ~ start(50)*1
h_0n ~~ start(70)*h_0n

## SLOPE - Growth

h_1n =~ 0*pvt8+pvt9+pvt10+pvt11+pvt12+pvt13+1*pvt14
h_1n~start(11.507)*1
h_1n~~start(2.184)*h_1n
h_1n~~start(10.752)*h_0n

#Mean of PVT
pvt8+pvt9+pvt10+pvt11+pvt12+pvt13+pvt14~0*1

#Specific Variance of Pvt
pvt8~~sigma2_s*pvt8
pvt9~~sigma2_s*pvt9
pvt10~~sigma2_s*pvt10
pvt11~~sigma2_s*pvt11
pvt12~~sigma2_s*pvt12
pvt13~~sigma2_s*pvt13
pvt14~~sigma2_s*pvt14



##MULTIVARIATE INFO
##FACTOR CORR

	b_0n 	~~sigma_b0_h0*h_0n
	b_0n 	~~sigma_b0_h1*h_1n 

	b_1n 	~~sigma_b1_h0*h_0n
	b_1n 	~~sigma_b1_h1*h_1n

#Specific Covariance
    pvt8   ~~(sigma_su)*total8  
    pvt9   ~~(sigma_su)*total9  
    pvt10  ~~(sigma_su)*total10 
    pvt11  ~~(sigma_su)*total11
    pvt12  ~~(sigma_su)*total12
    pvt13  ~~(sigma_su)*total13
    pvt14  ~~(sigma_su)*total14
'

lca_fit<-lavaan(biv_lca,data=data,missing='ML')
