
#####################################
### Bivariate LDS Growth Model
#####################################

library(lavaan)

data<-read.table("nlsy_ach_bpi1.dat",header=F,colClasses="numeric",
na.string=".")

#paste command - pattern to name columns
#paste0 = paste command with no separation
#paste0("tot",4:14) = "tot4","tot5",..."tot14"

names(data)<-c("id","race","sex","m_birth","ldisabil", 
	paste0("dep",4:14),paste0("tot",4:14),
	paste0("anti",4:14),paste0("axdp",4:14),
	paste0("math",5:14),paste0("rec",5:14),
	paste0("comp",4:14),paste0("pvt",4:14))

t<-which(data$ldisabil==1)

# Removes ldisabil = 1 from dataset
data<-data[-t,]

#access data columns easily by attaching it
attach(data)


##Define variables

    data$total8  = (((dep8  + anti8  + axdp8)-5.039)/4.076)*10+50;
    data$total9  = (((dep9  + anti9  + axdp9)-5.039)/4.076)*10+50;
    data$total10 = (((dep10 + anti10 + axdp10)-5.039)/4.076)*10+50;
    data$total11 = (((dep11 + anti11 + axdp11)-5.039)/4.076)*10+50;
    data$total12 = (((dep12 + anti12 + axdp12)-5.039)/4.076)*10+50;
    data$total13 = (((dep13 + anti13 + axdp13)-5.039)/4.076)*10+50;
    data$total14 = (((dep14 + anti14 + axdp14)-5.039)/4.076)*10+50;
##Define variables

    data$pvt8 = ((pvt8-82.130)/16.745)*10+50;
    data$pvt9 = ((pvt9-82.130)/16.745)*10+50;
    data$pvt10 = ((pvt10-82.130)/16.745)*10+50;
    data$pvt11 = ((pvt11-82.130)/16.745)*10+50;
    data$pvt12 = ((pvt12-82.130)/16.745)*10+50;
    data$pvt13 = ((pvt13-82.130)/16.745)*10+50;
    data$pvt14 = ((pvt14-82.130)/16.745)*10+50;


## No Coupling Model
 
biv_ldf<-'

#####
#BPI#
#####

#Modeling True Score

lt8=~1*total8
lt9=~1*total9
lt10=~1*total10
lt11=~1*total11
lt12=~1*total12
lt13=~1*total13
lt14=~1*total14

## AutoRegressions
lt9~1*lt8
lt10~1*lt9
lt11~1*lt10
lt12~1*lt11
lt13~1*lt12
lt14~1*lt13

## Difference Scores

dt9=~1*lt9
dt10=~1*lt10
dt11=~1*lt11
dt12=~1*lt12
dt13=~1*lt13
dt14=~1*lt14



## Level

b_0n=~ 1*lt8
total8+total9+total10+total11+total12+total13+total14~0*1
b_0n ~ start(50.205)*1
b_0n ~~ start(67.477)*b_0n

## Latent Means at zero

lt8+lt9+lt10+lt11+lt12+lt13+lt14~0*1
dt9+dt10+dt11+dt12+dt13+dt14~0*1

## Latent Variances to zero

lt8~~0*lt8
lt9~~0*lt9
lt10~~0*lt10
lt11~~0*lt11
lt12~~0*lt12
lt13~~0*lt13
lt14~~0*lt14

dt9~~0*dt9
dt10~~0*dt10
dt11~~0*dt11
dt12~~0*dt12
dt13~~0*dt13
dt14~~0*dt14

#Specific Variances
total8~~start(42.413)*total8+si*total8
total9~~start(42.413)*total9+si*total9
total10~~start(42.413)*total10+si*total10
total11~~start(42.413)*total11+si*total11
total12~~start(42.413)*total12+si*total12
total13~~start(42.413)*total13+si*total13
total14~~start(42.413)*total14+si*total14

## Proportional Change

dt9 ~ start(.172)*lt8+alpha_t*lt8
dt10 ~ start(.172)*lt9+alpha_t*lt9
dt11 ~ start(.172)*lt10+alpha_t*lt10
dt12 ~ start(.172)*lt11+alpha_t*lt11
dt13 ~ start(.172)*lt12+alpha_t*lt12
dt14 ~ start(.172)*lt13+alpha_t*lt13

## SLOPE - Growth

b_1n =~ 1*dt9+1*dt10+1*dt11+1*dt12+1*dt13+1*dt14
b_1n~start(-8.535)*1+beta_1*1
b_1n~~start(2.854)*b_1n+sigma2_b1*b_1n
b_1n~~start(-12.668)*b_0n+sb1b0*b_0n


#####
#PVT#
#####

#Modeling True Score
lp8=~1*pvt8
lp9=~1*pvt9
lp10=~1*pvt10
lp11=~1*pvt11
lp12=~1*pvt12
lp13=~1*pvt13
lp14=~1*pvt14

## AutoRegressions
lp9~1*lp8
lp10~1*lp9
lp11~1*lp10
lp12~1*lp11
lp13~1*lp12
lp14~1*lp13

## Difference Scores

dp9=~1*lp9
dp10=~1*lp10
dp11=~1*lp11
dp12=~1*lp12
dp13=~1*lp13
dp14=~1*lp14

##Level 

h_0n =~ 1*lp8

pvt8+pvt9+pvt10+pvt11+pvt12+pvt13+pvt14~0*1
h_0n ~ start(50.017)*1
h_0n ~~ start(77.327)*h_0n

## Latent Means at zero

lp8+lp9+lp10+lp11+lp12+lp13+lp14~0*1
dp9+dp10+dp11+dp12+dp13+dp14~0*1

## Latent Variances to zero

lp8~~0*lp8
lp9~~0*lp9
lp10~~0*lp10
lp11~~0*lp11
lp12~~0*lp12
lp13~~0*lp13
lp14~~0*lp14

dp9~~0*dp9
dp10~~0*dp10
dp11~~0*dp11
dp12~~0*dp12
dp13~~0*dp13
dp14~~0*dp14

#Specific Variances
pvt8~~start(22.339)*pvt8+sigma2_s*pvt8
pvt9~~start(22.339)*pvt9+sigma2_s*pvt9
pvt10~~start(22.339)*pvt10+sigma2_s*pvt10
pvt11~~start(22.339)*pvt11+sigma2_s*pvt11
pvt12~~start(22.339)*pvt12+sigma2_s*pvt12
pvt13~~start(22.339)*pvt13+sigma2_s*pvt13
pvt14~~start(22.339)*pvt14+sigma2_s*pvt14

## Proportional Change

dp9 ~ start(-.123)*lp8+B_pvt*lp8
dp10 ~ start(-.123)*lp9+B_pvt*lp9
dp11 ~ start(-.123)*lp10+B_pvt*lp10
dp12 ~ start(-.123)*lp11+B_pvt*lp11
dp13 ~ start(-.123)*lp12+B_pvt*lp12
dp14 ~ start(-.123)*lp13+B_pvt*lp13

## SLOPE - Growth

h_1n =~ 1*dp9+1*dp10+1*dp11+1*dp12+1*dp13+1*dp14
h_1n~start(11.507)*1
h_1n~~start(2.184)*h_1n
h_1n~~start(10.752)*h_0n

##MULTIVARIATE INFO
##FACTOR CORR

	b_0n 	~~start(-12.668)*h_0n+sigma_b0_h0*h_0n
	b_0n 	~~start(-1.896)*h_1n+sigma_b0_h1*h_1n 

	b_1n 	~~start(2.079)*h_0n+sigma_b1_h0*h_0n
	b_1n 	~~start(0.200)*h_1n+sigma_b1_h1*h_1n

#Specific Covariance
    pvt8   ~~start(-0.354)*total8+(sigma_su)*total8  
    pvt9   ~~start(-0.354)*total9+(sigma_su)*total9  
    pvt10  ~~start(-0.354)*total10+(sigma_su)*total10 
    pvt11  ~~start(-0.354)*total11+(sigma_su)*total11
    pvt12  ~~start(-0.354)*total12+(sigma_su)*total12
    pvt13  ~~start(-0.354)*total13+(sigma_su)*total13
    pvt14  ~~start(-0.354)*total14+(sigma_su)*total14

'

lcsm_fit<-lavaan(biv_ldf,data=data,missing="ML")
summary(lcsm_fit)
