##########################################

### Time-Varying Covariate Growth Model 2 

data<-read.table("nlsy_ach_bpi1.dat",header=F,colClasses="numeric",
na.string=".")

#paste command - pattern to name columns
#paste0 = paste command with no separation
#paste0("tot",4:14) = "tot4","tot5",..."tot14"

names(data)<-c("id","race","sex","m_birth","ldisabil", 
	paste0("dep",4:14),paste0("tot",4:14),
	paste0("anti",4:14),paste0("axdp",4:14),
	paste0("math",5:14),paste0("rec",5:14),
	paste0("comp",4:14),paste0("pvt",4:14))

t<-which(data$ldisabil==1)
data<-data[-t,]
#access data columns easily by attaching it
attach(data)



##Define variables

    data$total8  = (((dep8  + anti8  + axdp8)-5.039)/4.076)*10+50;
    data$total9  = (((dep9  + anti9  + axdp9)-5.039)/4.076)*10+50;
    data$total10 = (((dep10 + anti10 + axdp10)-5.039)/4.076)*10+50;
    data$total11 = (((dep11 + anti11 + axdp11)-5.039)/4.076)*10+50;
    data$total12 = (((dep12 + anti12 + axdp12)-5.039)/4.076)*10+50;
    data$total13 = (((dep13 + anti13 + axdp13)-5.039)/4.076)*10+50;
    data$total14 = (((dep14 + anti14 + axdp14)-5.039)/4.076)*10+50;
##Define variables

    data$pvt8 = ((pvt8-82.130)/16.745)*10+50;
    data$pvt9 = ((pvt9-82.130)/16.745)*10+50;
    data$pvt10 = ((pvt10-82.130)/16.745)*10+50;
    data$pvt11 = ((pvt11-82.130)/16.745)*10+50;
    data$pvt12 = ((pvt12-82.130)/16.745)*10+50;
    data$pvt13 = ((pvt13-82.130)/16.745)*10+50;
    data$pvt14 = ((pvt14-82.130)/16.745)*10+50;


##Model 2 for time-varying covariates

biv_tvc2<-'

#####
#PVT#
#####

##Level 

b_0n =~ 1*pvt8+1*pvt9+1*pvt10+1*pvt11+1*pvt12+1*pvt13+1*pvt14
b_0n ~ start(50)*1
b_0n ~~ start(75)*b_0n

## SLOPE - Growth

b_1n =~ 0*pvt8+start(.2)*pvt9+start(.4)*pvt10+start(.6)*pvt11+
start(.8)*pvt12+start(.9)*pvt13+1*pvt14
b_1n~start(23.9)*1
b_1n~~start(14)*b_1n
b_1n~~start(4.8)*b_0n

#Means of PVT to zero
pvt8+pvt9+pvt10+pvt11+pvt12+pvt13+pvt14~0*1

#Specific Variances
pvt8~~sigma2_u*pvt8
pvt9~~sigma2_u*pvt9
pvt10~~sigma2_u*pvt10
pvt11~~sigma2_u*pvt11
pvt12~~sigma2_u*pvt12
pvt13~~sigma2_u*pvt13
pvt14~~sigma2_u*pvt14


#intercept for total
total8+total9+total10+total11+total12+total13+total14~1

##saturate behavior with covariances
f_0n=~1*total8+start(1)*total9+start(1)*total10+
start(1)*total11+start(1)*total12+start(1)*total13+start(1)*total14
f_0n~~start(52)*f_0n

##variances 
total8~~total8
total9~~total9
total10~~total10
total11~~total11
total12~~total12
total13~~total13
total14~~total14

#Regressions
pvt8~gamma*total8
pvt9~gamma*total9
pvt10~gamma*total10
pvt11~gamma*total11
pvt12~gamma*total12
pvt13~gamma*total13
pvt14~gamma*total14

##Latent regressions

b_0n ~ start(-.2)*f_0n
b_1n ~ start(-.05)*f_0n

'

tvc2_fit<-lavaan(biv_tvc2,data=data,missing='ML')

